@@ -44,12 +44,12 @@ if get_backend()=='pytorch':
     from trident.layers.pytorch_blocks import *
     from trident.layers.pytorch_normalizations import *
     from trident.layers.pytorch_rnn import *
+    from trident.layers.pytorch_transformers import *
 
     from trident.optims.pytorch_constraints import *
     from trident.optims.pytorch_regularizers import *
     from trident.optims.pytorch_losses import *
     from trident.optims.pytorch_metrics import *
-
     from trident.optims.pytorch_trainer import *
 
 elif get_backend()=='tensorflow':
@@ -77,6 +77,11 @@ elif get_backend()=='onnx':
     import_or_install('onnx_runtime')
     pass
 
+from trident.data.transform import *
+from trident.data.vision_transforms import *
+from trident.data.text_transforms import *
+from trident.data.data_loaders import *
+
 from trident.optims.trainers import TrainingPlan
 from trident.misc.ipython_utils import *
 from trident.misc.visualization_utils import *
