@@ -599,8 +599,6 @@ class ModelBase(object):
             self.print_epoch_progress(self.training_context['print_epoch_progress_frequency'])
             # self.training_context['print_epoch_progress_frequency'] = 1
 
-        if self.training_context['current_epoch'] == self.training_context['total_epoch'] - 1:
-            self.do_on_training_end()
 
     def do_on_batch_start(self):
         for callback in self.training_context['callbacks']:
