@@ -140,25 +140,27 @@ class _ClassificationLoss(Loss):
 
     def flatten_check(self, output, target):
         "Check that `out` and `targ` have the same number of elements and flatten them."
+        ndim_output=ndim(output)
+        ndim_target=ndim(target)
         if ndim(output) > 2:
             if self.axis == 1:
                 output = reshape(output, (output.size(0), output.size(1), -1))
-                output = output.permute(0, 2, 1)
-                output = reshape(output, (-1, output.size(-1)))
-            elif self.axis == -1:
-                output = reshape(output, (-1, output.size(-1)))
 
-            if ndim(target) > 2 and target.dtype != dtype.long:
+
+            elif self.axis == -1:
+                output = reshape(output, (output.size(0),-1, output.size(-1)))
+
+            if ndim_target==ndim_output -1  and target.dtype == dtype.long:
+                target = reshape(target, (target.size(0), -1))
+
+            elif ndim_target==ndim_output  and target.dtype != dtype.long:
                 if self.axis == 1:
                     target = reshape(target, (target.size(0), target.size(1), -1))
-                    target = target.permute(0, 2, 1)
-                    target = reshape(target, (-1, target.size(-1)))
+
+
                 elif self.axis == -1:
                     target = reshape(target, (-1, target.size(-1)))
 
-
-            elif ndim(target) >= 2 and target.dtype == dtype.long:
-                target = reshape(target, (-1))
             return output.contiguous(), target
         elif ndim(output) <= 2 and len(output) == len(target):
             return output, target
@@ -213,7 +215,7 @@ class _ClassificationLoss(Loss):
                 if int_shape(output)[1] == len(self.label_statistics):
                     new_shp = [1] * len(int_shape(output))
                     new_shp[1] = len(self.label_statistics)
-                    output = output - to_tensor(np.reshape(np.log(np.clip(self.label_statistics.copy(),a_min=1e-7)), tuple(new_shp)))
+                    output = output - to_tensor(np.reshape(np.log(clip(self.label_statistics.copy(),min=1e-7)), tuple(new_shp)))
             output = clip(output, max=- 1e-7)
         else:
             self.is_logsoftmax = False
@@ -576,7 +578,7 @@ class CrossEntropyLoss(_ClassificationLoss):
 
         """
         loss = to_tensor(0.0)
-        output, target = self.flatten_check(output, target)
+
         sample_weight = cast(self.sample_weight, output.dtype) * cast(self.ignore_index_weight, output.dtype)
         if not self.need_target_onehot:
             if self.is_target_onehot and target.dtype != dtype.long:
@@ -875,7 +877,7 @@ class FocalLoss(_ClassificationLoss):
         Returns:
 
             """
-        output, target = self.flatten_check(output, target)
+
         if not self.need_target_onehot:
             if self.is_target_onehot:
                 target = argmax(target, self.axis)
