@@ -5,7 +5,7 @@ import math
 import os
 import sys
 from functools import partial
-
+from  typing import Union,Optional,List,Tuple
 import numpy as np
 import torch
 import torch.nn as nn
@@ -36,7 +36,7 @@ __all__ = ['accuracy','recall','pixel_accuracy','alpha_pixel_accuracy','iou','ps
 
 
 @torch.no_grad()
-def accuracy(output, target, topk=1,axis=1,ignore_index=-100, exclude_mask=False):
+def accuracy(output:Tensor, target:Tensor, topk:int=1,axis:int=1,ignore_index:Union[int,list]=-100, exclude_mask:bool=False):
     """Computes the precision@k for the specified values of k
     prec1, prec5 = accuracy(output.data, target, topk=(1, 5))
     """
@@ -94,7 +94,7 @@ def accuracy(output, target, topk=1,axis=1,ignore_index=-100, exclude_mask=False
 
 
 @torch.no_grad()
-def recall(output, target, axis=1,ignore_index=-100):
+def recall(output:Tensor, target:Tensor, axis=1,ignore_index=-100):
     """Computes the precision@k for the specified values of k
     prec1, prec5 = accuracy(output.data, target, topk=(1, 5))
     """
@@ -143,7 +143,7 @@ def recall(output, target, axis=1,ignore_index=-100):
 
 
 @torch.no_grad()
-def psnr(output, target):
+def psnr(output:Tensor, target:Tensor):
     input_tensor = output.clone().detach()
     target_tensor = target.clone().detach()
     if input_tensor.shape != target_tensor.shape :
@@ -163,7 +163,7 @@ def psnr(output, target):
     return psnr
 
 @torch.no_grad()
-def mean_absolute_error(output, target):
+def mean_absolute_error(output:Tensor, target:Tensor):
     input_tensor = output.view(-1).clone().detach()
     target_tensor = target.view(-1).clone().detach()
 
@@ -174,7 +174,7 @@ def mean_absolute_error(output, target):
 mae=mean_absolute_error
 
 @torch.no_grad()
-def mean_squared_error(output, target):
+def mean_squared_error(output:Tensor, target:Tensor):
     input_tensor = output.view(-1).clone().detach()
     target_tensor = target.view(-1).clone().detach()
 
@@ -187,7 +187,7 @@ mse=mean_squared_error
 
 
 @torch.no_grad()
-def root_mean_squared_error(output, target):
+def root_mean_squared_error(output:Tensor, target:Tensor):
     input_tensor=output.view(-1).clone().detach()
     target_tensor=target.view(-1).clone().detach()
 
@@ -198,7 +198,7 @@ rmse=root_mean_squared_error
 
 
 @torch.no_grad()
-def mean_squared_logarithmic_error(output, target):
+def mean_squared_logarithmic_error(output:Tensor, target:Tensor):
     input_tensor=output.view(-1).clone().detach()
     target_tensor=target.view(-1).clone().detach()
 
@@ -209,7 +209,7 @@ msle=mean_squared_logarithmic_error
 
 
 @torch.no_grad()
-def pixel_accuracy(output, target):
+def pixel_accuracy(output:Tensor, target:Tensor):
     input_tensor = output.clone().detach()
     target_tensor = target.clone().detach()
     if input_tensor.dtype!=torch.int64 :
@@ -238,7 +238,7 @@ def alpha_pixel_accuracy(output, alpha):
     return pixel_correct/max(pixel_labeled,1)
 
 @torch.no_grad()
-def iou(output, target):
+def iou(output:Tensor, target:Tensor):
     input_tensor = output.clone().detach()
     target_tensor = target.clone().detach()
     if input_tensor.dtype != torch.int64:
